@@ -32,13 +32,11 @@ rng_seq <- function(n, seed = NULL, simplify = FALSE) {
 
 # see https://stackoverflow.com/a/20998531/5793905 and the link there
 handle_rngkind <- function() {
-    current_seed <- get(".Random.seed", .GlobalEnv)
     previous_rngkind <- RNGkind(dtwclust_rngkind)[1L]
     if (previous_rngkind != dtwclust_rngkind) {
         # evaluate on.exit on the caller's environment, otherwise it would execute immediately
         do.call(on.exit, envir = parent.frame(), args = list(substitute({
             RNGkind(previous_rngkind)
-            assign(".Random.seed", current_seed, .GlobalEnv)
         })))
     }
     invisible()
